@@ -19,7 +19,7 @@
 
 #include "declarationnavigationcontext.h"
 
-#include <QtGui/QTextDocument>
+#include <QTextDocument>
 
 #include <klocalizedstring.h>
 
@@ -186,7 +186,7 @@ void DeclarationNavigationContext::htmlFunction()
     int currentArgNum = 0;
 
     QVector<Declaration*> decls;
-    if (DUContext* argumentContext = DUChainUtils::getArgumentContext(declaration().data())) {
+    if (DUContext* argumentContext = DUChainUtils::argumentContext(declaration().data())) {
       decls = argumentContext->localDeclarations(topContext().data());
     }
     foreach(const AbstractType::Ptr& argType, type->arguments()) {
@@ -196,7 +196,7 @@ void DeclarationNavigationContext::htmlFunction()
 
       VariableDeclaration *argDec = dynamic_cast<VariableDeclaration*>(decls[currentArgNum]);
 
-      if (argDec->isVariadic()) {
+      if (argDec && argDec->isVariadic()) {
         AbstractType::Ptr variadicType;
         const auto indexed = argType.cast<IndexedContainer>();
         if (indexed && indexed->typesCount() == 1) {
@@ -216,8 +216,12 @@ void DeclarationNavigationContext::htmlFunction()
           modifyHtml() += ' ' + identifierHighlight(decls[currentArgNum]->identifier().toString().toHtmlEscaped(), declaration());
         }
 
-        if( currentArgNum >= firstDefaultParam )
-          modifyHtml() += " = " + function->defaultParameters()[ currentArgNum - firstDefaultParam ].str().toHtmlEscaped();
+        if (currentArgNum >= firstDefaultParam) {
+          IndexedString defaultStr = function->defaultParameters()[currentArgNum - firstDefaultParam];
+          if (!defaultStr.isEmpty()) {
+            modifyHtml() += " = " + defaultStr.str().toHtmlEscaped();
+          }
+        }
       }
 
       ++currentArgNum;
@@ -228,12 +232,12 @@ void DeclarationNavigationContext::htmlFunction()
   modifyHtml() += QStringLiteral("<br />");
 }
 
-QualifiedIdentifier DeclarationNavigationContext::prettyQualifiedIdentifier( DeclarationPointer decl ) const
+QualifiedIdentifier DeclarationNavigationContext::prettyQualifiedIdentifier(const DeclarationPointer& decl) const
 {
     return QualifiedIdentifier(prettyName(decl.data()));
 }
 
-void DeclarationNavigationContext::makeLink(const QString& name, DeclarationPointer declaration, NavigationAction::Type actionType)
+void DeclarationNavigationContext::makeLink(const QString& name, const DeclarationPointer& declaration, NavigationAction::Type actionType)
 {
     if ( actionType == NavigationAction::JumpToSource && declaration->url() == internalFunctionFile() ) {
         modifyHtml() += i18n("PHP internal");
@@ -242,7 +246,7 @@ void DeclarationNavigationContext::makeLink(const QString& name, DeclarationPoin
     AbstractDeclarationNavigationContext::makeLink(name, declaration, actionType);
 }
 
-QString DeclarationNavigationContext::declarationKind(DeclarationPointer decl)
+QString DeclarationNavigationContext::declarationKind(const DeclarationPointer& decl)
 {
     if ( decl->kind() == Declaration::Instance && decl->abstractType()
          && decl->abstractType()->modifiers() & AbstractType::ConstModifier ) {
